@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
 version: 1.4.13.2
-id: yesod-auth-1.4.13.2-e638e081132a85618f37f43080bc4eb4
-key: yesod_1AbRBQZZLwxL7hUDre699C
+id: yesod-auth-1.4.13.2-ee0da37f7df57ee3b9394d8946c3e74c
+key: yesod_H7pQG2CQmk5LFmE5qTyQTq
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13.2
-hs-libraries: HSyesod-auth-1.4.13.2-1AbRBQZZLwxL7hUDre699C
+hs-libraries: HSyesod-auth-1.4.13.2-H7pQG2CQmk5LFmE5qTyQTq
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
-    authenticate-1.3.3.1-d5d29d33a55e5a55915307e270a92892
+    authenticate-1.3.3.1-1ffb6b37ef80e337dac8818012820cef
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -37,21 +37,21 @@ depends:
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
-    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
     data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     email-validate-2.2.0-b56e57eb2689ad2a5bb9495f35baa8f4
     file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
-    http-client-0.4.28-bc84c1de0ba23b26cbd36cc941948a7e
-    http-conduit-2.1.10.1-25cf7e0ab425a3f9a6e4adec2d684722
+    http-client-0.4.28-d9eaa96ad0af94307689994faa8b7f4a
+    http-conduit-2.1.10.1-06d6cae4a7dc7e652455c24a41eb9def
     http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     mime-mail-0.4.11-d9015aaaa236b99cae24cbb7fe985a3e
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
     nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
-    persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
-    persistent-template-2.1.6-83163c252d18f4a1e745e383b4fcf281
+    persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
+    persistent-template-2.1.6-0f50ab49755373ba8c00624f7c433aaf
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     safe-0.3.9-b613242f536083d5bb04920ede356aea
@@ -62,9 +62,9 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
-    yesod-core-1.4.20.2-aced7b6b1008af0f1a8e5e3876fc55af
-    yesod-form-1.4.7.1-5d1acfd5ba57bcb9acd30a4f556f6cdd
-    yesod-persistent-1.4.0.5-a3f7b6a3b9261de48209b70a4cc548df
+    yesod-core-1.4.20.2-014d072d2152bbd04ae4cfe76f84438d
+    yesod-form-1.4.7.1-ba5ac4a6723307832a83abce64a93dfc
+    yesod-persistent-1.4.0.5-b1c3c9997492fcc63225dc59ed6cb11e
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
